Change Log
==========

..
   All enhancements and patches to eox_audit_model will be documented
   in this file.  It adheres to the structure of http://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).
   
   This project adheres to Semantic Versioning (http://semver.org/).
.. There should always be an "Unreleased" section for changes pending release.
Unreleased
----------

*

[0.1.0] - 2020-08-18
---------------------

Added
~~~~~

* First release on PyPI.
